@@ -25,7 +25,7 @@ def setup():
     source_format = args.source_format
     destination = args.destination
     format = args.format
-    if args.conf_file is not None and args.conf_file is "config.py":
+    if not args.conf_file == None and args.conf_file == "config.py":
         config = __import__("config")
         flag = False
 
@@ -58,7 +58,7 @@ def setup():
         convert(source, source_format, destination, format)
 
 
-def convert(source, source_format, dest, dest_format):
+def convert(source: str, source_format: str, dest: str, dest_format: str):
     if dest_format.upper() not in formats.keys():
         raise ValueError('Invalid format')
 
